<?php

/**
 * @file 
 * Rules configuration forms for Signup Status Rules module
 *
 * @ingroup rules
 */

/**
 * Condition: Signup status has value configuration form.
 */
function signup_status_rules_condition_status_has_value_form($settings, &$form) {
  $form['settings']['signup_status'] = _signup_status_rules_status_form($settings);
}

/**
 * Form for setting a signup status.
 */
function signup_status_rules_action_set_status_form($settings, &$form) {
  $form['settings']['signup_status'] = _signup_status_rules_status_form($settings);
}

/**
 * Helper function for building a status form.
 */
function _signup_status_rules_status_form($settings) {
  $statuses = signup_status_rules_get_statuses();
  $options = array();
  foreach ($statuses as $sid => $status) {
    $options[$sid] = $status->name;
  }
  $settings += array('status' => array());
  return array(
    '#type' => 'select',
    '#title' => t('Updated status'),
    '#options' => $options,
    '#multiple' => FALSE,
    '#default_value' => isset($settings['status']) ? $settings['status'] : array(),
    '#required' => TRUE,
  );
}

/**
 * Get available signup statuses
 */
function signup_status_rules_get_statuses() {
  static $statuses = array();
  if (empty($statuses)) {
    $result = db_query("SELECT * FROM {signup_status_codes} ORDER BY weight");
    while ($status = db_fetch_object($result)) {
      $statuses[$status->cid] = $status;
    }
  }
  return $statuses;
}

/**
 * Action: Mail signup users configuration form.
 */
function signup_status_rules_action_mail_users_form($settings, &$form) {
  $statuses = signup_status_rules_get_statuses();
  $options = array();
  foreach ($statuses as $sid => $status) {
    $options[$sid] = $status->name;
  }

  // Retrieve the normal mail form and add status options.
  module_load_include('inc', 'signup_rules', 'signup_rules.rules_forms');
  signup_rules_action_mail_to_signup_users_form($settings, $form);
  $form['settings']['limit']['#multiple'] = TRUE;
  $form['settings']['limit']['#options'] = array_merge($form['settings']['limit']['#options'], $options);
}

/**
 * validation callback for send mail action.
 */
function signup_status_rules_action_mail_users_validate($form, $form_state) {
  $from = $form_state['values']['settings']['from'];
  if (!empty($from) && !valid_email_address($from)) {
    form_set_error('from', t('You must enter a valid e-mail address.'));
  }
}
